import { NextRequest, NextResponse } from 'next/server';
import { cookies } from 'next/headers';
import { getLogger } from '@/lib/logger';

// Base URL for Vultr API
const VULTR_API_BASE_URL = 'https://api.vultr.com/v2';

// Cookie name for storing the API key
const API_KEY_COOKIE = 'vultr_api_key';

// Helper function to get API key from cookies
function getApiKey(): string | null {
  const cookieStore = cookies();
  return cookieStore.get(API_KEY_COOKIE)?.value || null;
}

// Set export const dynamic to force dynamic rendering
export const dynamic = 'force-dynamic';

// Handler for PATCH requests (update DNS record)
export async function PATCH(
  request: NextRequest,
  { params }: { params: { domain: string; recordId: string } }
) {
  const logger = getLogger();
  const startTime = Date.now();
  const { domain, recordId } = params;
  
  // Check if user is authenticated
  const apiKey = getApiKey();
  if (!apiKey) {
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'PATCH',
      endpoint: `/api/vultr/domains/${domain}/records/${recordId}`,
      statusCode: 401,
      responseTime: Date.now() - startTime,
      error: 'Authentication required'
    });
    
    return NextResponse.json(
      { error: 'Authentication required' },
      { status: 401 }
    );
  }
  
  try {
    const body = await request.json();
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'PATCH',
      endpoint: `${VULTR_API_BASE_URL}/domains/${domain}/records/${recordId}`,
      requestBody: body,
      apiKey
    });
    
    const response = await fetch(`${VULTR_API_BASE_URL}/domains/${domain}/records/${recordId}`, {
      method: 'PATCH',
      headers: {
        'Authorization': `Bearer ${apiKey}`,
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(body),
    });

    const data = await response.json();
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'PATCH',
      endpoint: `${VULTR_API_BASE_URL}/domains/${domain}/records/${recordId}`,
      statusCode: response.status,
      responseTime: Date.now() - startTime,
      apiKey
    });

    if (!response.ok) {
      return NextResponse.json(
        { error: data.error || `Failed to update DNS record ${recordId}` },
        { status: response.status }
      );
    }

    return NextResponse.json({ record: data.record });
  } catch (error) {
    const errorMessage = error instanceof Error ? error.message : 'Unknown error';
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'PATCH',
      endpoint: `/api/vultr/domains/${domain}/records/${recordId}`,
      statusCode: 500,
      responseTime: Date.now() - startTime,
      error: errorMessage,
      apiKey
    });
    
    console.error(`Error updating DNS record ${recordId}:`, error);
    return NextResponse.json(
      { error: 'Internal server error' },
      { status: 500 }
    );
  }
}

// Handler for DELETE requests (delete DNS record)
export async function DELETE(
  request: NextRequest,
  { params }: { params: { domain: string; recordId: string } }
) {
  const logger = getLogger();
  const startTime = Date.now();
  const { domain, recordId } = params;
  
  // Check if user is authenticated
  const apiKey = getApiKey();
  if (!apiKey) {
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'DELETE',
      endpoint: `/api/vultr/domains/${domain}/records/${recordId}`,
      statusCode: 401,
      responseTime: Date.now() - startTime,
      error: 'Authentication required'
    });
    
    return NextResponse.json(
      { error: 'Authentication required' },
      { status: 401 }
    );
  }
  
  try {
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'DELETE',
      endpoint: `${VULTR_API_BASE_URL}/domains/${domain}/records/${recordId}`,
      apiKey
    });
    
    const response = await fetch(`${VULTR_API_BASE_URL}/domains/${domain}/records/${recordId}`, {
      method: 'DELETE',
      headers: {
        'Authorization': `Bearer ${apiKey}`,
        'Content-Type': 'application/json',
      },
    });
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'DELETE',
      endpoint: `${VULTR_API_BASE_URL}/domains/${domain}/records/${recordId}`,
      statusCode: response.status,
      responseTime: Date.now() - startTime,
      apiKey
    });

    if (!response.ok) {
      const errorData = await response.json().catch(() => ({}));
      return NextResponse.json(
        { error: errorData.error || `Failed to delete DNS record ${recordId}` },
        { status: response.status }
      );
    }

    return NextResponse.json({ success: true });
  } catch (error) {
    const errorMessage = error instanceof Error ? error.message : 'Unknown error';
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'DELETE',
      endpoint: `/api/vultr/domains/${domain}/records/${recordId}`,
      statusCode: 500,
      responseTime: Date.now() - startTime,
      error: errorMessage,
      apiKey
    });
    
    console.error(`Error deleting DNS record ${recordId}:`, error);
    return NextResponse.json(
      { error: 'Internal server error' },
      { status: 500 }
    );
  }
}
