import { NextRequest, NextResponse } from 'next/server';
import { cookies } from 'next/headers';
import { getLogger } from '@/lib/logger';

// Base URL for Vultr API
const VULTR_API_BASE_URL = 'https://api.vultr.com/v2';

// Cookie name for storing the API key
const API_KEY_COOKIE = 'vultr_api_key';

// Helper function to get API key from cookies
function getApiKey(): string | null {
  const cookieStore = cookies();
  return cookieStore.get(API_KEY_COOKIE)?.value || null;
}

// Set export const dynamic to force dynamic rendering
export const dynamic = 'force-dynamic';

// Handler for GET requests (list DNS records)
export async function GET(
  request: NextRequest,
  { params }: { params: { domain: string } }
) {
  const logger = getLogger();
  const startTime = Date.now();
  const domain = params.domain;
  
  // Check if user is authenticated
  const apiKey = getApiKey();
  if (!apiKey) {
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'GET',
      endpoint: `/api/vultr/domains/${domain}/records`,
      statusCode: 401,
      responseTime: Date.now() - startTime,
      error: 'Authentication required'
    });
    
    return NextResponse.json(
      { error: 'Authentication required' },
      { status: 401 }
    );
  }
  
  try {
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'GET',
      endpoint: `${VULTR_API_BASE_URL}/domains/${domain}/records`,
      apiKey
    });
    
    const response = await fetch(`${VULTR_API_BASE_URL}/domains/${domain}/records`, {
      headers: {
        'Authorization': `Bearer ${apiKey}`,
        'Content-Type': 'application/json',
      },
    });

    const data = await response.json();
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'GET',
      endpoint: `${VULTR_API_BASE_URL}/domains/${domain}/records`,
      statusCode: response.status,
      responseTime: Date.now() - startTime,
      apiKey
    });

    if (!response.ok) {
      return NextResponse.json(
        { error: data.error || `Failed to fetch DNS records for ${domain}` },
        { status: response.status }
      );
    }

    return NextResponse.json({ records: data.records });
  } catch (error) {
    const errorMessage = error instanceof Error ? error.message : 'Unknown error';
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'GET',
      endpoint: `/api/vultr/domains/${domain}/records`,
      statusCode: 500,
      responseTime: Date.now() - startTime,
      error: errorMessage,
      apiKey
    });
    
    console.error(`Error fetching DNS records for ${domain}:`, error);
    return NextResponse.json(
      { error: 'Internal server error' },
      { status: 500 }
    );
  }
}

// Handler for POST requests (create DNS record)
export async function POST(
  request: NextRequest,
  { params }: { params: { domain: string } }
) {
  const logger = getLogger();
  const startTime = Date.now();
  const domain = params.domain;
  
  // Check if user is authenticated
  const apiKey = getApiKey();
  if (!apiKey) {
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'POST',
      endpoint: `/api/vultr/domains/${domain}/records`,
      statusCode: 401,
      responseTime: Date.now() - startTime,
      error: 'Authentication required'
    });
    
    return NextResponse.json(
      { error: 'Authentication required' },
      { status: 401 }
    );
  }
  
  try {
    const body = await request.json();
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'POST',
      endpoint: `${VULTR_API_BASE_URL}/domains/${domain}/records`,
      requestBody: body,
      apiKey
    });
    
    const response = await fetch(`${VULTR_API_BASE_URL}/domains/${domain}/records`, {
      method: 'POST',
      headers: {
        'Authorization': `Bearer ${apiKey}`,
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(body),
    });

    const data = await response.json();
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'POST',
      endpoint: `${VULTR_API_BASE_URL}/domains/${domain}/records`,
      statusCode: response.status,
      responseTime: Date.now() - startTime,
      apiKey
    });

    if (!response.ok) {
      return NextResponse.json(
        { error: data.error || `Failed to create DNS record for ${domain}` },
        { status: response.status }
      );
    }

    return NextResponse.json({ record: data.record });
  } catch (error) {
    const errorMessage = error instanceof Error ? error.message : 'Unknown error';
    
    logger.log({
      timestamp: new Date().toISOString(),
      method: 'POST',
      endpoint: `/api/vultr/domains/${domain}/records`,
      statusCode: 500,
      responseTime: Date.now() - startTime,
      error: errorMessage,
      apiKey
    });
    
    console.error(`Error creating DNS record for ${domain}:`, error);
    return NextResponse.json(
      { error: 'Internal server error' },
      { status: 500 }
    );
  }
}
